"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Markdown = void 0;
const common_1 = require("./utils/common");
__exportStar(require("./utils/common"), exports);
class Markdown {
    constructor(title) {
        this.LINES = [];
        if (!title) {
            throw new TypeError('Must Provide a title for this markdown');
        }
        this.header(title, 1);
    }
    tableOfContent(onTop = true) {
        var _a;
        let list = [];
        if (!this.LINES.length)
            return;
        for (const line of this.LINES) {
            if (line.startsWith('#')) {
                const depth = line.split('#').filter((c) => c === '').length - 1;
                const text = (_a = line.match(/^\#+\s?(.*)$/)) === null || _a === void 0 ? void 0 : _a[1];
                if (!text && !depth)
                    continue;
                list.push({ text, depth });
            }
        }
        this.list(list);
        if (onTop) {
            const lng = this.LINES.length;
            const toc = this.LINES.splice(lng - 1, 1);
            this.LINES.splice(1, 0, '## Table of Contents', ...toc);
        }
        return this;
    }
    render() {
        return this.LINES.join(common_1.CR);
    }
    addLine(data = common_1.LB) {
        this.LINES.push(`${data}`);
        return this;
    }
    paragraph(data) {
        this.addLine(`${data}`);
        return this;
    }
    header(title, n = 1) {
        this.addLine(`${'#'.repeat(n)} ${title}`);
        return this;
    }
    image(filepath, altText) {
        const str = `![${altText || filepath}](${filepath})`;
        this.addLine(str);
        return this;
    }
    table(columns = [], rows = [], fmtFnc) {
        this.addLine((0, common_1.table)(columns, rows, fmtFnc));
        return this;
    }
    list(items = [], numbered = false) {
        if (!Array.isArray(items)) {
            throw new TypeError('List items should be an array of { text: string, depth: number}');
        }
        let list = [];
        for (let i = 0; i < items.length; i++) {
            let parsed;
            const { text, depth } = items[i];
            if (numbered)
                parsed = `${i + 1}. ${text}`;
            else {
                parsed = `${!depth ? '' : '  '.repeat(depth)}- ${text}`;
            }
            list.push(parsed);
        }
        this.addLine(list.join('\n'));
        return this;
    }
    tasks(items = []) {
        if (!Array.isArray(items)) {
            throw new TypeError('List items should be an array of { text: string, checked: boolean }');
        }
        let list = [];
        for (let i = 0; i < items.length; i++) {
            const { text, checked } = items[i];
            const parsed = `- [${checked ? 'X' : ' '}] ${text}`;
            list.push(parsed);
        }
        this.addLine(list.join('\n'));
        return this;
    }
}
exports.Markdown = Markdown;
